==> free-1.4.tar.gz: FREE-1.4/ERServer/ERFrame2.java <==
/*
 * FREE 2000
 *
 * Copyright (c) Jason Kitcat, University of Warwick
 *
 * jeep@thecouch.org   http://www.thecouch.org/free/
 *
 * Knoll Cottage, Sutton Place, Nr.Abinger, Dorking, Surrey RH5 6RN United Kingdom
 *
 * Tel: 07956 886 508  Fax: 0870 052 7114
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program (gpl.txt); if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */
 
package ERServer;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.text.*;

/*
 * Simple database console for executing SQL queries.
 *
 * @version 0.2 15 March 2000
 * @author Jason Kitcat
 */
public class ERFrame2 extends JFrame 
{

	javax.swing.JLabel jLabel1 = new javax.swing.JLabel();
	javax.swing.JTextField jTextField1 = new javax.swing.JTextField();
	javax.swing.JButton jButton1 = new javax.swing.JButton();
	javax.swing.JLabel jLabel2 = new javax.swing.JLabel();
	javax.swing.JScrollPane jScrollPane1 = new javax.swing.JScrollPane();
	javax.swing.JTextPane jTextPane1 = new javax.swing.JTextPane();

	public ERFrame2() {
		jLabel1.setText("Results:");
		jLabel1.setVisible(true);
		jLabel1.setPreferredSize(new java.awt.Dimension(210, 20));
		jLabel1.setMinimumSize(new java.awt.Dimension(210, 20));
		jLabel1.setAlignmentX(LEFT_ALIGNMENT);

		jScrollPane1.setVisible(true);
		jScrollPane1.setPreferredSize(new java.awt.Dimension(330, 210));
		jScrollPane1.setMinimumSize(new java.awt.Dimension(165, 105));
		jScrollPane1.setAlignmentX(LEFT_ALIGNMENT);
		jScrollPane1.getViewport().add(jTextPane1);

		jTextPane1.setVisible(true);

		jLabel2.setText("Command entry:");
		jLabel2.setVisible(true);
		jLabel2.setPreferredSize(new java.awt.Dimension(230, 20));
		jLabel2.setAlignmentX(LEFT_ALIGNMENT);

		JPanel scrollPanel = new JPanel();
		scrollPanel.setLayout(new BoxLayout(scrollPanel, BoxLayout.Y_AXIS));
		scrollPanel.add(jLabel1);
		scrollPanel.add(Box.createRigidArea(new java.awt.Dimension(0,5)));
		scrollPanel.add(jScrollPane1);
		scrollPanel.add(Box.createRigidArea(new java.awt.Dimension(0,5)));
		scrollPanel.add(jLabel2);
		scrollPanel.setBorder(BorderFactory.createEmptyBorder(10,10,10,10));

		jTextField1.setVisible(true);
		jTextField1.setPreferredSize(new java.awt.Dimension(390, 20));
		//jTextField1.setMinimumSize(new java.awt.Dimension(195, 20));

		jButton1.setText("Go");
		jButton1.setVisible(true);
		jButton1.setToolTipText("Click to execute your command");
		jButton1.setPreferredSize(new java.awt.Dimension(50, 20));
		jButton1.setMinimumSize(new java.awt.Dimension(50, 20));

		JPanel buttonPane = new JPanel();
		buttonPane.setLayout(new BoxLayout(buttonPane, BoxLayout.X_AXIS));
		buttonPane.setBorder(BorderFactory.createEmptyBorder(10,10,10,10));
		buttonPane.add(Box.createHorizontalGlue());
		buttonPane.add(jTextField1);
		buttonPane.add(Box.createRigidArea(new Dimension(10,0)));
		buttonPane.add(jButton1);

		setLocation(new java.awt.Point(40, 40));
		setTitle("FREE: Database Console");
		setSize(new java.awt.Dimension(472, 315));
		Container contentPane = getContentPane();
		contentPane.add(scrollPanel, BorderLayout.CENTER);
		contentPane.add(buttonPane, BorderLayout.SOUTH);
	
	}

	public void initComponents() throws Exception
	{
		jButton1.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent e) {
				jButton1ActionPerformed(e);
			}
		});
		addWindowListener(new java.awt.event.WindowAdapter() {
			public void windowClosing(java.awt.event.WindowEvent e) {
				thisWindowClosing(e);
			}
		});
// END GENERATED CODE
	}
  
  	private boolean mShown = false;
  	
	public void addNotify() 
	{
		super.addNotify();
		
		if (mShown)
			return;
			
		// resize frame to account for menubar
		JMenuBar jMenuBar = getJMenuBar();
		if (jMenuBar != null) {
			int jMenuBarHeight = jMenuBar.getPreferredSize().height;
			Dimension dimension = getSize();
			dimension.height += jMenuBarHeight;
			setSize(dimension);
		}

		mShown = true;
	}

	// Show an informational message (black, plain text)
	protected void showInfo(String msg) {
		SimpleAttributeSet attrs = new SimpleAttributeSet();
		StyleConstants.setForeground(attrs, Color.black);
		showMsg(msg, attrs);
	}
  
	// Show an warning message (red, bold text)
	protected void showError(String msg) {
		SimpleAttributeSet attrs = new SimpleAttributeSet();
		StyleConstants.setForeground(attrs, Color.red);
		StyleConstants.setBold(attrs, true);
		showMsg(msg, attrs);
	}
	
	// Show a text message using the specified AttributeSet
	protected void showMsg(String msg, AttributeSet attrs) {
		Document doc = jTextPane1.getDocument();
		msg += "\n";
		try {
			doc.insertString(doc.getLength(), msg, attrs);
		} catch (BadLocationException ex) {
			ex.printStackTrace();
		}
	}

	// Close the window when the close box is clicked
	void thisWindowClosing(java.awt.event.WindowEvent e)
	{
		ERServer.frame.jButton1.setEnabled(true);
		setVisible(false);
	}
	
	public void jButton1ActionPerformed(java.awt.event.ActionEvent e) {
	
		String userCommand = jTextField1.getText();
	
		showInfo("Executing: " + userCommand);
		jTextField1.setText("");
	
		DBase.doSQL(userCommand);
	
	}
		
}

==> free-1.5.tar.gz: FREE-1.5/ERServer/ERFrame2.java <==
/*
 * GNU.FREE 2001
 *
 * Copyright (c) 1999, 2000, 2001 The Free Software Foundation (www.fsf.org)
 *
 * GNU.FREE Co-ordinator: Jason Kitcat <jeep@thecouch.org>
 *
 * GNU site: http://www.gnu.org/software/gnu.free/gnufree.html
 * 
 * FREE e-democracy site: http://www.thecouch.org/free/
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program (gpl.txt); if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */
 
package ERServer;

import java.awt.*;
import java.awt.event.*;

import Free.awt.*;

/*
 * Simple database console for executing SQL queries.
 *
 * @version 0.3 31 January 2001
 * @author Jason Kitcat, Rajagopal C.V
 */
public class ERFrame2 extends Frame 
{

	Label jLabel1 = new Label();
	TextField jTextField1 = new TextField();
	Button jButton1 = new Button();
	Label jLabel2 = new Label();
	TextArea jTextPane1 = new TextArea();

	public Insets getInsets(){ return new Insets(30, 10, 10, 10);}

	public ERFrame2() {
		setTitle("FREE: Database Console");
		jLabel1.setText("Results:");
		jButton1.setLabel("Go");
		jLabel2.setText("Command entry:");

		FreePanel scrollPanel = new FreePanel("ER Server Results");
		scrollPanel.setInsets(3, 3, 3, 3);
		
		scrollPanel.addComponent( 0, 0, 1, 2, 0, 0, GridBagConstraints.BOTH, 
			1.0f, 1.0f, jTextPane1);
		scrollPanel.addComponent( 1, 0, 1, 1, 0, 0, GridBagConstraints.BOTH, 
			1.0f, 0.0f, jLabel2);
		scrollPanel.addComponent( 2, 0, 1, 1, 0, 0, GridBagConstraints.BOTH, 
			1.0f, 0.0f, jTextField1);
		scrollPanel.addComponent( 2, 1, 1, 1, 0, 0, GridBagConstraints.BOTH, 
			1.0f, 0.0f, jButton1);
			
		add(scrollPanel, BorderLayout.CENTER);
		setSize(new java.awt.Dimension(472, 315));
	
	}

	public void initComponents() throws Exception
	{
		jButton1.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent e) {
				jButton1ActionPerformed(e);
			}
		});
		addWindowListener(new java.awt.event.WindowAdapter() {
			public void windowClosing(java.awt.event.WindowEvent e) {
				thisWindowClosing(e);
			}
		});
// END GENERATED CODE
	}

	// Show an informational message (black, plain text)
	protected void showInfo(String msg) {
		showMsg(msg);
	}
  
	// Show an warning message (red, bold text)
	protected void showError(String msg) {
		showMsg(msg);
	}
	
	// Show a text message using the specified AttributeSet
	protected void showMsg(String msg) {
		msg += "\n";
		jTextPane1.setText(jTextPane1.getText() + msg);
	}
	
	// Close the window when the close box is clicked
	void thisWindowClosing(java.awt.event.WindowEvent e)
	{
		ERServer.frame.jButton1.setEnabled(true);
		setVisible(false);
	}
	
	public void jButton1ActionPerformed(java.awt.event.ActionEvent e) {
	
		String userCommand = jTextField1.getText();
	
		showInfo("Executing: " + userCommand);
		jTextField1.setText("");
	
		DBase.doSQL(userCommand);
	
	}
		
}
